from setuptools import setup

setup(name='maximshumilo_tools',
      version='0.2.10',
      description='Gaussian and Binomial distributions',
      packages=['ms_tools', 'ms_tools.flask', 'ms_tools.yandex_cloud', 'ms_tools.flask.test_case'],
      author_email='shumilo.mk@gmail.com',
      zip_safe=False)
